

## Experimental

```{eval-rst}
.. module:: scanpy.experimental
.. currentmodule:: scanpy
```

New methods that are in early development which are not (yet)
integrated in Scanpy core.

```{eval-rst}
.. module:: scanpy.experimental.pp
.. currentmodule:: scanpy
```

```{eval-rst}
.. autosummary::
   :nosignatures:
   :toctree: ../generated/

   experimental.pp.normalize_pearson_residuals
   experimental.pp.normalize_pearson_residuals_pca
   experimental.pp.highly_variable_genes
   experimental.pp.recipe_pearson_residuals
```
